==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-faq-light/dictionaries/ja.dict.itop-faq-light.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('JA JP', 'Japanese', '日本語', [
	'Brick:Portal:FAQ:Menu' => 'FAQ~~',
	'Brick:Portal:FAQ:Title' => 'Frequently Asked Questions~~',
	'Brick:Portal:FAQ:Title+' => '<p>In a hurry?</p><p>Check out the list of most common questions and (maybe) find the expected answer right away.</p>~~',
	'Class:FAQ' => 'FAQ',
	'Class:FAQ+' => 'よくある質問',
	'Class:FAQ/Attribute:category_id' => 'カテゴリ',
	'Class:FAQ/Attribute:category_id+' => '',
	'Class:FAQ/Attribute:category_name' => 'カテゴリ名',
	'Class:FAQ/Attribute:category_name+' => '',
	'Class:FAQ/Attribute:description' => '説明',
	'Class:FAQ/Attribute:description+' => '',
	'Class:FAQ/Attribute:domains' => 'Domains~~',
	'Class:FAQ/Attribute:error_code' => 'エラーコード',
	'Class:FAQ/Attribute:error_code+' => '',
	'Class:FAQ/Attribute:key_words' => 'キーワード',
	'Class:FAQ/Attribute:key_words+' => '',
	'Class:FAQ/Attribute:summary' => '要約',
	'Class:FAQ/Attribute:summary+' => '',
	'Class:FAQ/Attribute:title' => 'タイトル',
	'Class:FAQ/Attribute:title+' => '',
	'Class:FAQCategory' => 'FAQカテゴリ',
	'Class:FAQCategory+' => 'FAQのためのカテゴリ',
	'Class:FAQCategory/Attribute:faq_list' => 'FAQ',
	'Class:FAQCategory/Attribute:faq_list+' => 'All the frequently asked questions related to this category~~',
	'Class:FAQCategory/Attribute:name' => '名前',
	'Class:FAQCategory/Attribute:name+' => '',
	'Menu:FAQ' => 'FAQ',
	'Menu:FAQ+' => '全FAQ',
	'Menu:FAQCategory' => 'FAQカテゴリ',
	'Menu:FAQCategory+' => '全てのFAQカテゴリ',
	'Menu:Problem:Shortcuts' => 'ショートカット',
	'Menu:ProblemManagement' => '問題管理',
	'Menu:ProblemManagement+' => '問題管理',
]);

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-faq-light/dictionaries/ja.dict.itop-faq-light.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('JA JP', 'Japanese', '日本語', array(
	'Class:FAQ' => 'FAQ',
	'Class:FAQ+' => 'よくある質問',
	'Class:FAQ/Attribute:title' => 'タイトル',
	'Class:FAQ/Attribute:title+' => '',
	'Class:FAQ/Attribute:summary' => '要約',
	'Class:FAQ/Attribute:summary+' => '',
	'Class:FAQ/Attribute:description' => '説明',
	'Class:FAQ/Attribute:description+' => '',
	'Class:FAQ/Attribute:category_id' => 'カテゴリ',
	'Class:FAQ/Attribute:category_id+' => '',
	'Class:FAQ/Attribute:category_name' => 'カテゴリ名',
	'Class:FAQ/Attribute:category_name+' => '',
	'Class:FAQ/Attribute:error_code' => 'エラーコード',
	'Class:FAQ/Attribute:error_code+' => '',
	'Class:FAQ/Attribute:key_words' => 'キーワード',
	'Class:FAQ/Attribute:key_words+' => '',
	'Class:FAQ/Attribute:domains' => 'Domains~~',
));

//
// Class: FAQCategory
//

Dict::Add('JA JP', 'Japanese', '日本語', array(
	'Class:FAQCategory' => 'FAQカテゴリ',
	'Class:FAQCategory+' => 'FAQのためのカテゴリ',
	'Class:FAQCategory/Attribute:name' => '名前',
	'Class:FAQCategory/Attribute:name+' => '',
	'Class:FAQCategory/Attribute:faq_list' => 'FAQ',
	'Class:FAQCategory/Attribute:faq_list+' => 'All the frequently asked questions related to this category~~',
));
Dict::Add('JA JP', 'Japanese', '日本語', array(
	'Menu:ProblemManagement' => '問題管理',
	'Menu:ProblemManagement+' => '問題管理',
	'Menu:Problem:Shortcuts' => 'ショートカット',
	'Menu:FAQCategory' => 'FAQカテゴリ',
	'Menu:FAQCategory+' => '全てのFAQカテゴリ',
	'Menu:FAQ' => 'FAQ',
	'Menu:FAQ+' => '全FAQ',
	'Brick:Portal:FAQ:Menu' => 'FAQ~~',
	'Brick:Portal:FAQ:Title' => 'Frequently Asked Questions~~',
	'Brick:Portal:FAQ:Title+' => '<p>In a hurry?</p><p>Check out the list of most common questions and (maybe) find the expected answer right away.</p>~~',
));
